@@ -374,7 +374,7 @@ static int mix_selection(chan_info *cp, sync_info *si_out, mus_long_t beg, io_er
   io_error_t io_err;
 
   tempfile = snd_tempnam();
-  io_err = save_selection(tempfile, snd_srate(cp->sound), MUS_OUT_SAMPLE_TYPE, MUS_NEXT, NULL, SAVE_ALL_CHANS);
+  io_err = save_selection(tempfile, snd_srate(cp->sound), MUS_OUT_SAMPLE_TYPE, MUS_NEXT, NULL, SAVE_ALL_CHANS); /* should this use DEFAULT_OUTPUT_HEADER_TYPE? */
   if (io_err == IO_NO_ERROR)
     {
       char *origin = NULL;
@@ -438,7 +438,7 @@ static io_error_t insert_selection(chan_info *cp, sync_info *si_out, mus_long_t
   mus_sample_t out_format = MUS_OUT_SAMPLE_TYPE;
   io_error_t io_err = IO_NO_ERROR;
 
-  if (mus_header_writable(MUS_NEXT, cp->sound->hdr->sample_type))
+  if (mus_header_writable(MUS_NEXT, cp->sound->hdr->sample_type)) /* should these use DEFAULT_OUTPUT_HEADER_TYPE? */
     out_format = cp->sound->hdr->sample_type;
   tempfile = snd_tempnam();
 
@@ -996,7 +996,7 @@ static Xen s7_xen_selection_copy(s7_scheme *sc, Xen args)
       snd_info *sp;
       char *name;
       name = snd_tempnam();
-      save_selection(name, selection_srate(), MUS_OUT_SAMPLE_TYPE, MUS_NEXT, NULL, SAVE_ALL_CHANS);
+      save_selection(name, selection_srate(), MUS_OUT_SAMPLE_TYPE, MUS_NEXT, NULL, SAVE_ALL_CHANS); /* should this use DEFAULT_OUTPUT_HEADER_TYPE? */
       sp = snd_open_file(name, FILE_READ_WRITE);
       free(name);
       return(new_xen_sound(sp->index));
@@ -1101,7 +1101,7 @@ io_error_t save_selection(const char *ofile, int srate, mus_sample_t samp_type,
     {
       if ((sp) && (mus_header_writable(sp->hdr->type, MUS_IGNORE_SAMPLE)))
 	head_type = sp->hdr->type;
-      else head_type = MUS_NEXT;
+      else head_type = default_output_header_type(ss) ; /* was MUS_NEXT, 28-Jul-23 */
     }
   if (samp_type == MUS_UNKNOWN_SAMPLE)
     {
@@ -1415,7 +1415,7 @@ static Xen g_selection_to_mix(void)
       cp = si_out->cps[0];
 
       tempfile = snd_tempnam();
-      io_err = save_selection(tempfile, snd_srate(cp->sound), MUS_OUT_SAMPLE_TYPE, MUS_NEXT, NULL, SAVE_ALL_CHANS);
+      io_err = save_selection(tempfile, snd_srate(cp->sound), MUS_OUT_SAMPLE_TYPE, MUS_NEXT, NULL, SAVE_ALL_CHANS); /* should this use DEFAULT_OUTPUT_HEADER_TYPE? */
       if (is_serious_io_error(io_err))
 	{
 	  if (tempfile) free(tempfile);
